==> fediz-1.6.1-source-release.zip: fediz-1.6.1/systests/tomcat/src/test/java/org/apache/cxf/fediz/systests/tomcat/ClientCertificateTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.fediz.systests.tomcat;

import org.apache.cxf.fediz.systests.common.AbstractClientCertTests;

import org.junit.AfterClass;
import org.junit.BeforeClass;

/**
 * In this test-case, the IdP is set up to require client authentication, rather than authenticating using a
 * username + password, or via Kerberos.
 */
public class ClientCertificateTest extends AbstractClientCertTests {

    private static final String SERVLET_CONTEXT_NAME = "fedizhelloworld_client_cert";

    @BeforeClass
    public static void init() throws Exception {
        TomcatLauncher.startServer(SERVLET_CONTEXT_NAME);
    }

    @AfterClass
    public static void cleanup() throws Exception {
        TomcatLauncher.shutdownServer();
    }

    public String getIdpHttpsPort() {
        return TomcatLauncher.getIdpHttpsPort();
    }

    public String getRpHttpsPort() {
        return TomcatLauncher.getRpHttpsPort();
    }

    public String getServletContextName() {
        return SERVLET_CONTEXT_NAME;
    }

}

==> fediz-1.7.1-source-release.zip: fediz-1.7.1/systests/tomcat/src/test/java/org/apache/cxf/fediz/systests/tomcat/ClientCertificateTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.fediz.systests.tomcat;

import org.apache.cxf.fediz.systests.common.AbstractClientCertTests;

import org.junit.jupiter.api.AfterAll;
import org.junit.jupiter.api.BeforeAll;

/**
 * In this test-case, the IdP is set up to require client authentication, rather than authenticating using a
 * username + password, or via Kerberos.
 */
public class ClientCertificateTest extends AbstractClientCertTests {

    private static final String SERVLET_CONTEXT_NAME = "fedizhelloworld_client_cert";

    @BeforeAll
    public static void init() throws Exception {
        TomcatLauncher.startServer(SERVLET_CONTEXT_NAME);
    }

    @AfterAll
    public static void cleanup() throws Exception {
        TomcatLauncher.shutdownServer();
    }

    public String getIdpHttpsPort() {
        return TomcatLauncher.getIdpHttpsPort();
    }

    public String getRpHttpsPort() {
        return TomcatLauncher.getRpHttpsPort();
    }

    public String getServletContextName() {
        return SERVLET_CONTEXT_NAME;
    }

}
